@@ -220,56 +220,56 @@ def calc_linerange(node):
 
 def linerange(node):
     """Get line number range from a node."""
-    if hasattr(node, "_bandit_linerange_stripped"):
-        lines_minmax = node._bandit_linerange_stripped
-        return list(range(lines_minmax[0], lines_minmax[1] + 1))
+    if sys.version_info >= (3, 8) and hasattr(node, "lineno"):
+        return list(range(node.lineno, node.end_lineno + 1))
+    else:
+        if hasattr(node, "_bandit_linerange_stripped"):
+            lines_minmax = node._bandit_linerange_stripped
+            return list(range(lines_minmax[0], lines_minmax[1] + 1))
 
-    strip = {
-        "body": None,
-        "orelse": None,
-        "handlers": None,
-        "finalbody": None,
-    }
-    for key in strip.keys():
-        if hasattr(node, key):
-            strip[key] = getattr(node, key)
-            setattr(node, key, [])
+        strip = {
+            "body": None,
+            "orelse": None,
+            "handlers": None,
+            "finalbody": None,
+        }
+        for key in strip.keys():
+            if hasattr(node, key):
+                strip[key] = getattr(node, key)
+                setattr(node, key, [])
 
-    lines_min = 9999999999
-    lines_max = -1
-    if hasattr(node, "lineno"):
-        lines_min = node.lineno
-        lines_max = node.lineno
-    for n in ast.iter_child_nodes(node):
-        lines_minmax = calc_linerange(n)
-        lines_min = min(lines_min, lines_minmax[0])
-        lines_max = max(lines_max, lines_minmax[1])
+        lines_min = 9999999999
+        lines_max = -1
+        if hasattr(node, "lineno"):
+            lines_min = node.lineno
+            lines_max = node.lineno
+        for n in ast.iter_child_nodes(node):
+            lines_minmax = calc_linerange(n)
+            lines_min = min(lines_min, lines_minmax[0])
+            lines_max = max(lines_max, lines_minmax[1])
 
-    for key in strip.keys():
-        if strip[key] is not None:
-            setattr(node, key, strip[key])
+        for key in strip.keys():
+            if strip[key] is not None:
+                setattr(node, key, strip[key])
 
-    if lines_max == -1:
-        lines_min = 0
-        lines_max = 1
+        if lines_max == -1:
+            lines_min = 0
+            lines_max = 1
 
-    node._bandit_linerange_stripped = (lines_min, lines_max)
+        node._bandit_linerange_stripped = (lines_min, lines_max)
 
-    return list(range(lines_min, lines_max + 1))
+        lines = list(range(lines_min, lines_max + 1))
 
-
-def linerange_fix(node):
-    """Try and work around a known Python bug with multi-line strings."""
-    # deal with multiline strings lineno behavior (Python issue #16806)
-    lines = linerange(node)
-    if hasattr(node, "_bandit_sibling") and hasattr(
-        node._bandit_sibling, "lineno"
-    ):
-        start = min(lines)
-        delta = node._bandit_sibling.lineno - start
-        if delta > 1:
-            return list(range(start, node._bandit_sibling.lineno))
-    return lines
+        """Try and work around a known Python bug with multi-line strings."""
+        # deal with multiline strings lineno behavior (Python issue #16806)
+        if hasattr(node, "_bandit_sibling") and hasattr(
+            node._bandit_sibling, "lineno"
+        ):
+            start = min(lines)
+            delta = node._bandit_sibling.lineno - start
+            if delta > 1:
+                return list(range(start, node._bandit_sibling.lineno))
+        return lines
 
 
 def concat_string(node, stop=None):
@@ -370,3 +370,11 @@ def check_ast_node(name):
         pass
 
     raise TypeError("Error: %s is not a valid node type in AST" % name)
+
+
+def get_nosec(nosec_lines, context):
+    for lineno in context["linerange"]:
+        nosec = nosec_lines.get(lineno, None)
+        if nosec is not None:
+            return nosec
+    return None
