@@ -17,8 +17,8 @@ This formatter outputs the issues as color coded text to screen.
 
        Severity: Medium   Confidence: High
        CWE: CWE-20 (https://cwe.mitre.org/data/definitions/20.html)
-       Location: examples/yaml_load.py:5
        More Info: https://bandit.readthedocs.io/en/latest/
+       Location: examples/yaml_load.py:5
     4       ystr = yaml.dump({'a' : 1, 'b' : 2, 'c' : 3})
     5       y = yaml.load(ystr)
     6       yaml.dump(y)
@@ -128,21 +128,19 @@ def _output_issue_str(
 
     bits.append(f"{indent}   CWE: {str(issue.cwe)}")
 
+    bits.append(f"{indent}   More Info: {docs_utils.get_url(issue.test_id)}")
+
     bits.append(
-        "%s   Location: %s:%s:%s"
+        "%s   Location: %s:%s:%s%s"
         % (
             indent,
             issue.fname,
             issue.lineno if show_lineno else "",
             issue.col_offset if show_lineno else "",
+            COLOR["DEFAULT"],
         )
     )
 
-    bits.append(
-        "%s   More Info: %s%s"
-        % (indent, docs_utils.get_url(issue.test_id), COLOR["DEFAULT"])
-    )
-
     if show_code:
         bits.extend(
             [indent + line for line in issue.get_code(lines, True).split("\n")]
