@@ -18,6 +18,7 @@ binding to all network interfaces.
 
     >> Issue: Possible binding to all interfaces.
        Severity: Medium   Confidence: Medium
+       CWE: CWE-605 (https://cwe.mitre.org/data/definitions/605.html)
        Location: ./examples/binding.py:4
     3   s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
     4   s.bind(('0.0.0.0', 31137))
@@ -26,11 +27,16 @@ binding to all network interfaces.
 .. seealso::
 
  - https://nvd.nist.gov/vuln/detail/CVE-2018-1281
+ - https://cwe.mitre.org/data/definitions/605.html
 
 .. versionadded:: 0.9.0
 
+.. versionchanged:: 1.7.3
+    CWE information added
+
 """
 import bandit
+from bandit.core import issue
 from bandit.core import test_properties as test
 
 
@@ -41,5 +47,6 @@ def hardcoded_bind_all_interfaces(context):
         return bandit.Issue(
             severity=bandit.MEDIUM,
             confidence=bandit.MEDIUM,
+            cwe=issue.Cwe.MULTIPLE_BINDS,
             text="Possible binding to all interfaces.",
         )
