@@ -6,6 +6,7 @@ import ast
 import re
 
 import bandit
+from bandit.core import issue
 from bandit.core import test_properties as test
 
 
@@ -19,6 +20,7 @@ def _report(value):
     return bandit.Issue(
         severity=bandit.LOW,
         confidence=bandit.MEDIUM,
+        cwe=issue.Cwe.HARD_CODED_PASSWORD,
         text=("Possible hardcoded password: '%s'" % value),
     )
 
@@ -34,6 +36,7 @@ def hardcoded_password_string(context):
 
     - assigned to a variable that looks like a password
     - assigned to a dict key that looks like a password
+    - assigned to a class attribute that looks like a password
     - used in a comparison with a variable that looks like a password
 
     Variables are considered to look like a password if they have match any one
@@ -59,6 +62,7 @@ def hardcoded_password_string(context):
 
         >> Issue: Possible hardcoded password '(root)'
            Severity: Low   Confidence: Low
+           CWE: CWE-259 (https://cwe.mitre.org/data/definitions/259.html)
            Location: ./examples/hardcoded-passwords.py:5
         4 def someFunction2(password):
         5     if password == "root":
@@ -67,9 +71,13 @@ def hardcoded_password_string(context):
     .. seealso::
 
         - https://www.owasp.org/index.php/Use_of_hard-coded_password
+        - https://cwe.mitre.org/data/definitions/259.html
 
     .. versionadded:: 0.9.0
 
+    .. versionchanged:: 1.7.3
+        CWE information added
+
     """
     node = context.node
     if isinstance(node._bandit_parent, ast.Assign):
@@ -77,6 +85,10 @@ def hardcoded_password_string(context):
         for targ in node._bandit_parent.targets:
             if isinstance(targ, ast.Name) and RE_CANDIDATES.search(targ.id):
                 return _report(node.s)
+            elif isinstance(targ, ast.Attribute) and RE_CANDIDATES.search(
+                targ.attr
+            ):
+                return _report(node.s)
 
     elif isinstance(
         node._bandit_parent, ast.Subscript
@@ -107,6 +119,10 @@ def hardcoded_password_string(context):
             if RE_CANDIDATES.search(comp.left.id):
                 if isinstance(comp.comparators[0], ast.Str):
                     return _report(comp.comparators[0].s)
+        elif isinstance(comp.left, ast.Attribute):
+            if RE_CANDIDATES.search(comp.left.attr):
+                if isinstance(comp.comparators[0], ast.Str):
+                    return _report(comp.comparators[0].s)
 
 
 @test.checks("Call")
@@ -143,6 +159,7 @@ def hardcoded_password_funcarg(context):
         >> Issue: [B106:hardcoded_password_funcarg] Possible hardcoded
         password: 'blerg'
            Severity: Low   Confidence: Medium
+           CWE: CWE-259 (https://cwe.mitre.org/data/definitions/259.html)
            Location: ./examples/hardcoded-passwords.py:16
         15
         16    doLogin(password="blerg")
@@ -150,9 +167,13 @@ def hardcoded_password_funcarg(context):
     .. seealso::
 
         - https://www.owasp.org/index.php/Use_of_hard-coded_password
+        - https://cwe.mitre.org/data/definitions/259.html
 
     .. versionadded:: 0.9.0
 
+    .. versionchanged:: 1.7.3
+        CWE information added
+
     """
     # looks for "function(candidate='some_string')"
     for kw in context.node.keywords:
@@ -194,6 +215,7 @@ def hardcoded_password_default(context):
         >> Issue: [B107:hardcoded_password_default] Possible hardcoded
         password: 'Admin'
            Severity: Low   Confidence: Medium
+           CWE: CWE-259 (https://cwe.mitre.org/data/definitions/259.html)
            Location: ./examples/hardcoded-passwords.py:1
 
         1    def someFunction(user, password="Admin"):
@@ -202,9 +224,13 @@ def hardcoded_password_default(context):
     .. seealso::
 
         - https://www.owasp.org/index.php/Use_of_hard-coded_password
+        - https://cwe.mitre.org/data/definitions/259.html
 
     .. versionadded:: 0.9.0
 
+    .. versionchanged:: 1.7.3
+        CWE information added
+
     """
     # looks for "def function(candidate='some_string')"
 
