@@ -36,7 +36,7 @@ If so, a MEDIUM issue is reported. For example:
     construction.
        Severity: Medium   Confidence: Low
        CWE: CWE-89 (https://cwe.mitre.org/data/definitions/89.html)
-       Location: ./examples/sql_statements_without_sql_alchemy.py:4
+       Location: ./examples/sql_statements.py:4
     3 query = "DELETE FROM foo WHERE id = '%s'" % identifier
     4 query = "UPDATE foo SET value = 'b' WHERE id = '%s'" % identifier
     5
@@ -92,8 +92,18 @@ def _evaluate_ast(node):
     elif hasattr(ast, "JoinedStr") and isinstance(
         node._bandit_parent, ast.JoinedStr
     ):
-        statement = node.s
-        wrapper = node._bandit_parent._bandit_parent
+        substrings = [
+            child
+            for child in node._bandit_parent.values
+            if isinstance(child, ast.Str)
+        ]
+        # JoinedStr consists of list of Constant and FormattedValue
+        # instances. Let's perform one test for the whole string
+        # and abandon all parts except the first one to raise one
+        # failed test instead of many for the same SQL statement.
+        if substrings and node == substrings[0]:
+            statement = "".join([str(child.s) for child in substrings])
+            wrapper = node._bandit_parent._bandit_parent
 
     if isinstance(wrapper, ast.Call):  # wrapped in "execute" call?
         names = ["execute", "executemany"]
